# Sebastian Raschka 2022
# cyclemoid_pytorch
# Author: Sebastian Raschka <mail@sebastianraschka.com>
#
# License: MIT

from .cyclemoid import CycleMoid
from .cyclemoid import cyclemoid

__version__ = '1.0.0'


__all__ = ['CycleMoid', 'cyclemoid']